@@ -32,6 +32,11 @@ impl Dependency {
         format!("{} }}\n", output)
     }
 
+    #[cfg(test)]
+    pub fn name(&self) -> &str {
+        &self.name
+    }
+
     #[cfg(test)]
     pub fn version(&self) -> &str {
         &self.version
